Exception: LeanPool::ShutdownError
- Defined in:
- lib/lean_pool/errors.rb
Overview
Raised when attempting to use a pool that has been shutdown.
This error is raised when attempting to checkout a resource from a pool that has been shut down. Once a pool is shutdown, it cannot be used for new operations unless it is reloaded.